@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Artist;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 =head1 NAME
 
@@ -37,11 +37,13 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 relation_list()
 
+=head2 relation_lists()
+
 =head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_begin life_span_end alias_list release_list relation_list score/);
+__PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_begin life_span_end alias_list release_list relation_list relation_lists score/);
 
 =head1 AUTHOR
 
